
/**
*Description - Use PCML to call iSeries ILE program
*/ 

// Imports
import java.util.*;
import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.ibm.connector.*;
import com.ibm.connector.as400.*;
import com.ibm.as400.access.*;

public class WitPlaceOrderServlet extends HttpServlet implements Serializable
{
  /*****************************************************************************
  * Process incoming requests for information form a GET
  */
  public void doGet(HttpServletRequest request, HttpServletResponse response)
  {
     performTask(request, response);
  }
  
  /*****************************************************************************
  * Process incoming requests for information form a POST
  */
  public void doPost(HttpServletRequest request, HttpServletResponse response)
  {
     performTask(request, response);
  }

  public void performTask(HttpServletRequest request, HttpServletResponse response)
  {
     try {

		System.out.println("In WitPlaceOrderServlet");
       String sJobNumber = "";
       String projectName = "SV000618";
       String errorPage = "";
       boolean bTraceToErrorPage = false;
       ProgramCallCommand aProgramCallCommand = null;
       String tracePrefix = "WDT400:";
       HttpSession session = request.getSession(true);
       System.out.println( tracePrefix + " Servlet starts");
       tracePrefix += session.getId() + ":";
       aProgramCallCommand = new ProgramCallCommand( session, request, response, this, errorPage);
       if (session.isNew() || session.getAttribute("connctionSpec") == null) {
          System.out.println( tracePrefix + " setting up for new session");
          AS400ConnectionSpec connSpec = (AS400ConnectionSpec)aProgramCallCommand.getConnectionSpec();
          connSpec.setProjectName(projectName);
          connSpec.setServer(getServletContext().getInitParameter("WDT_HOSTNAME"));
          connSpec.setLogonID(getServletContext().getInitParameter("WDT_USERID"));
          connSpec.setLogonPassword(getServletContext().getInitParameter("WDT_PASSWORD"));
          String llist = getServletContext().getInitParameter("WDT_RUNTIMELIB");
          if (llist != null && llist.length()>0) {
             StringTokenizer token = new StringTokenizer(llist);
             int i = 0;
             Vector lib = new Vector();
             while (token.hasMoreElements()) {
                lib.addElement(token.nextToken());
                i++;
             }
             if (lib.size()>0) {
                String[] libl = new String[lib.size()];
                for (int j=0; j<lib.size(); j++)
                   libl[j] = (String)lib.elementAt(j);
                connSpec.setAS400LibList(libl);
             }
          }
          String traceFlag = getServletContext().getInitParameter("FLGERRORDETAILS");
          if (traceFlag != null && traceFlag.equalsIgnoreCase("true"))
             session.setAttribute("Affinity_TraceToErrorPage", new Boolean(true));
          session.setAttribute("Affinity_SessionListener", new AffinityBindingListener());
       }

       if (session.getAttribute("Affinity_TraceToErrorPage") != null && ((Boolean)session.getAttribute("Affinity_TraceToErrorPage")).booleanValue())
          bTraceToErrorPage = true;
       AS400 as400 = aProgramCallCommand.getAS400Object();
       sJobNumber = com.ibm.webtools.as400.GenericDebugSupport.getJobNumber(as400);
       tracePrefix += sJobNumber + ";";
       aProgramCallCommand.setTraceToErrorPage(bTraceToErrorPage, tracePrefix);
       //Clear error
       session.removeAttribute("Affinity_ErrorField");
       session.removeAttribute("Affinity_ErrorMessageText");

       //handle next/prev navigation
       String nextPage = request.getParameter("affinity_next");
       if(nextPage == null || nextPage.trim().length() == 0)
           nextPage = request.getParameter("affinity_previous");
       if(nextPage != null && nextPage.trim().length() > 0) {
           if(nextPage.charAt(0)!='/')
               nextPage = "/" + nextPage;
           getServletContext().getRequestDispatcher(nextPage).forward(request,response);
           return;
       }

       //Clean session variables
       Enumeration en = session.getAttributeNames();
       if(en != null)
           while(en.hasMoreElements()){
             String affinityName = (String)en.nextElement();
             if(affinityName != null && (affinityName.indexOf("Affinity_I_") == 0 || affinityName.indexOf("Affinity_O_") == 0))
                session.removeAttribute(affinityName);
       }
       session.setAttribute("Affinity_O_prodno",session.getAttribute("prodno"));
       session.setAttribute("Affinity_O_desc",session.getAttribute("desc"));
       session.setAttribute("Affinity_O_cost",session.getAttribute("cost"));
       nextPage ="/order.jsp";
        
       //Forward the request to the next page
       RequestDispatcher dispatch = request.getRequestDispatcher(nextPage);
       dispatch.forward(request, response);
    }
    catch (Throwable theException)
    {
         handleError(request, response, theException);
    }
  }


  public void handleError(HttpServletRequest request, 
                           HttpServletResponse response, 
                           Throwable e)
  {
     try
     {
        String message = e.getLocalizedMessage();
      	String stackTrace = printStackToString(e);
      	response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, message + 
      	                                 "<BR><BR><PRE>\n" + stackTrace + "</PRE>");
     }
     catch(Throwable ex)
     {
        ex.printStackTrace();
     } 
  }

    
   /**
   * This will return an exception's stack trace as a String.
   */
   public static synchronized String printStackToString(Throwable aThrowable) 
   {
      try
      {
         ByteArrayOutputStream stream = new ByteArrayOutputStream();
         PrintWriter aPrintWriter = new PrintWriter(stream, true);
         aThrowable.printStackTrace(aPrintWriter);
         aPrintWriter.flush();
         aPrintWriter.close();
         stream.flush();
         stream.close();
         return stream.toString();
      }
      catch(Throwable ex) 
      { 
         return aThrowable.toString();
      }
  }

  

}

